\name{express}
\alias{express}
%- Also NEED an `\alias' for EACH other topic documented here.
\title{Expression}
\description{
Computes expression measures for probe level data
}
\usage{
express(x, method=c("avglogpm", "li.wong", "avdiff"), normalize=T,
        normalize.method=c("quantile", "loess", "contrasts"), span=2/3,
        choose.subset=T, subset.size=5000, verbose=T, maxit=1)
}
\arguments{
  \item{x}{a \code{\link{probe.level.object}}.}
  \item{method}{which method to use to compute measure of expression,
    "avglogpm", "li.wong", or "avdiff".}
  \item{normalize}{logical value. If \code{TRUE} normalize probe level
    data before computing expression measures.}
  \item{normalize.method}{which normalization method to use, "quantile", "loess" or "contrasts".}
  \item{span}{\code{\link{loess}} span to use with "loess" and "contrast"
    methods.}
  \item{choose.subset}{logical value. For the "loess" and "contrast"
    methods, if \code{TRUE} it will do normalization on a subset and
    predict for the rest.}
  \item{subset.size}{size of subset to use in normalization.}
  \item{verbose}{logical value. If \code{TRUE} it writes out some messages.}
  \item{maxit}{maximum number of iterations to use in method "loess".}
}
\details{
 "avglogpm" is the recommended method. It uses a background corrected
 average of PM values as a measure of expression. "li.wong" uses the Li
 and Wong algorithm. "avdiff" uses Genechip's average difference.}
}
\value{A matrix with expression values (genes represented by rows)}
\examples{
     data(plob.example)
     E <- express(plob.example)
     par(mfrow=c(1,1))
     plot(E[,1],E[,2],log="xy")
}
\references{Irizarry, R.A., et al. (2001) \url{http://biosun01.biostat.jhsph.edu/~ririzarr/papers/index.html}}
  }
\author{Rafael A. Irizarry}
\seealso{\code{\link{li.wong}}, \code{\link{avdiff}}}
\keyword{manip}
\keyword{models}
